<?php

declare(strict_types=1);

namespace app\models;

class AccountEdgeOrder extends Edge
{
    public static function collectionName(): string
    {
        return 'account_edge_order';
    }

    /**
     * Поиск по идентификатору заказа
     *
     * @param string $order_id Идентификатор записи заказа в базе данных
     * @param int $limit Ограничение
     *
     * @return array|null
     */
    public static function searchByOrder(string $order_id, int $limit = 1): ?array
    {
        return self::find()->where(['_to' => $order_id])->limit($limit)->all();
    }

    /**
     * Генерация ярлыка на русском языке для статуса заказа
     *
     * @param string $status Статус заказа
     *
     * @return string Ярлык статуса на русском языке
     */
    public static function statusToRussian(string $status = ''): string
    {
        return match ($status) {
            'requested' => 'Запрошен',
            'accepted' => 'Ожидается отправка',
            'going' => 'Доставляется',
            'completed' => 'Завершен',
            default => 'Обрабатывается'
        };
    }
}
